@@ -9,6 +9,9 @@ import warnings
 here = str(Path(__file__).resolve().parent)
 directory_name = here.replace(str(Path(__file__).resolve().parent.parent), "").replace("/", "")  # gross solution
 instruments = {}
+
+
+
 for directory in os.scandir(here):
     if directory.is_dir() and not directory.name.__contains__("__"):
         modules = {}
@@ -18,7 +21,11 @@ for directory in os.scandir(here):
                 sname = str(file).replace(".py", "")
                 try:
                     module = import_module(f"{directory_name}.{directory.name}.{sname}")
-                    modules[module.name] = {"name": module.name, "module": module, "hwid": module.hwid}
+                    try:
+                        serial = module.serial_number
+                    except:
+                        serial = "any"
+                    modules[module.name] = {"name": module.name, "module": module, "hwid": module.hwid,"serial": serial}
                 except Exception as ex:
                     print(f"{file} import failed")
                     print(ex)
@@ -38,7 +45,12 @@ for directory in os.scandir(here):
                 try:
                     name = module.name
                     hwid = module.hwid
-                    modules = {name: {"name": name, "module": module, "hwid": hwid}}
+                    try:
+                        serial = module.serial_number
+                    except:
+                        serial = "any"
+
+                    modules = {name: {"name": name, "module": module, "hwid": hwid, "serial": serial}}
                     globals()[name] = Instrument(modules=modules, name=name)
                 except:
                     name = sname
@@ -48,3 +60,4 @@ for directory in os.scandir(here):
             except Exception as ex:
                 print(f"{file} import failed")
                 print(ex)
+
