@@ -14,17 +14,8 @@ def find_ports():
 class instrument:
     def __init__(self, port):
         self.rotator = elliptec.Motor(port.device)
-        self.home()
         self.max_degree = 180
         self.min_degree = -180
-        '''
-        elif type == "thorlabs_apt":
-            rotator = apt.Motor(i[1])
-            rotator.set_move_home_parameters(2, 1, 10, 0)
-            rotator.set_velocity_parameters(0, 10, 10)
-            rotator.move_home()
-            return rotator
-        '''
 
     def home(self):
         self.degree = 0
